#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-reify-many
version:              0.1.10
visibility:           public
id:                   th-reify-many-0.1.10-3nEZfG4JrET7STF9qM5wsn
key:                  th-reify-many-0.1.10-3nEZfG4JrET7STF9qM5wsn
license:              BSD-3-Clause
maintainer:           Michael Sloan <mgsloan at gmail>
author:               Michael Sloan
stability:            Experimental
homepage:             http://github.com/mgsloan/th-reify-many
synopsis:             Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.

category:             Template Haskell
abi:                  888ec4b5121ae9e9e15b7056a032a8fc
exposed:              True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-reify-many-0.1.10
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-reify-many-0.1.10
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-reify-many-0.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-reify-many
hs-libraries:         HSth-reify-many-0.1.10-3nEZfG4JrET7STF9qM5wsn
depends:
    base-4.18.2.1 containers-0.6.7 mtl-2.3.1
    safe-0.3.21-KdE8f1g6p6v53Pxmzg6oHI template-haskell-2.20.0.0
    th-expand-syns-0.4.12.0-Gv7Ja57BQZnGuhJ6xb0H0W

haddock-interfaces:
    /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock

haddock-html:         /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

